==> insightconnect_integrations_validators-2.13.0-py3-none-any.whl: icon_validator/rules/plugin_validators/title_validator.py <==
from icon_validator.rules.validator import KomandPluginValidator
from icon_validator.exceptions import ValidationException


class TitleValidator(KomandPluginValidator):

    @staticmethod
    def validate_title(title, plugin_title=False):
        if title.endswith("."):
            raise ValidationException("Title ends with period when it should not.")
        if title[0].islower() and not plugin_title:
            # This plugin title is OK: minFraud
            # This plugin title is OK: ifconfig.co
            raise ValidationException("Title should not start with a lower case letter.")
        if title[0].isspace():
            raise ValidationException("Title should not start with a whitespace character.")
        if len(title.split()) > 7:
            raise ValidationException(f"Title is too long, 6 words or less: contains {str(len(title.split()))}")
        for word in title.split():
            if not title.startswith(word):
                if "The" == word:
                    raise ValidationException("Title contains a capitalized 'The' when it should not.")
                if "By" == word and not title.endswith("By"):
                    # This is OK: Order By
                    # This is NOT OK: Search By String
                    raise ValidationException("Title contains a capitalized 'By' when it should not.")
                if "From" == word:
                    raise ValidationException("Title contains a capitalized 'From' when it should not.")
                if "A" == word:
                    raise ValidationException("Title contains a capitalized 'A' when it should not.")
                if "An" == word:
                    raise ValidationException("Title contains a capitalized 'An' when it should not.")
                if "Of" == word and not title.endswith("Of"):
                    # This is OK: Member Of
                    # This is NOT OK: Type Of String
                    raise ValidationException("Title contains a capitalized 'Of' when it should not.")

    @staticmethod
    def validate_actions(dict_, dict_key):
        if dict_key in dict_:
            TitleValidator.validate_dictionary(dict_, dict_key)
            for key, value in dict_[dict_key].items():
                if "input" in value:
                    TitleValidator.validate_dictionary(value, "input")
                if "output" in value:
                    TitleValidator.validate_dictionary(value, "output")

    @staticmethod
    def validate_dictionary(dict_, dict_key):
        if dict_key in dict_:
            if not dict_[dict_key]:
                return

            for key, value in dict_[dict_key].items():
                if "name" in value:
                    raise ValidationException(f"Deprecated 'name' key '{value}' found when 'title' should be used instead.")
                if "title" in value:
                    try:
                        TitleValidator.validate_title(value["title"], plugin_title=False)
                    except Exception as e:
                        raise ValidationException(f"{dict_key} key '{key}'\'s title ends with period when it should not.", e)

    @staticmethod
    def validate_plugin_title(spec):
        if "title" not in spec.spec_dictionary():
            raise ValidationException("Plugin title is missing.")

        try:
            TitleValidator.validate_title(spec.spec_dictionary()["title"], plugin_title=True)
        except Exception as e:
            raise ValidationException("Plugin title not valid.", e)

    def validate(self, spec):
        TitleValidator.validate_plugin_title(spec)
        TitleValidator.validate_actions(spec.spec_dictionary(), "actions")
        TitleValidator.validate_actions(spec.spec_dictionary(), "triggers")
        TitleValidator.validate_actions(spec.spec_dictionary(), "connection")

==> insightconnect_integrations_validators-2.16.0-py3-none-any.whl: icon_validator/rules/plugin_validators/title_validator.py <==
from icon_validator.rules.validator import KomandPluginValidator
from icon_validator.exceptions import ValidationException


class TitleValidator(KomandPluginValidator):

    @staticmethod
    def validate_title(title, plugin_title=False):
        if not isinstance(title, str):
            raise ValidationException("Title must not be blank")
        if title == "":
            raise ValidationException("Title must not be blank")
        if title.endswith("."):
            raise ValidationException("Title ends with period when it should not.")
        if title[0].islower() and not plugin_title:
            # This plugin title is OK: minFraud
            # This plugin title is OK: ifconfig.co
            raise ValidationException("Title should not start with a lower case letter.")
        if title[0].isspace():
            raise ValidationException("Title should not start with a whitespace character.")
        if len(title.split()) > 7:
            raise ValidationException(f"Title is too long, 6 words or less: contains {str(len(title.split()))}")
        for word in title.split():
            if not title.startswith(word):
                # TODO I want to pull from a list file rather than having to update this list in 3 areas every time we need a change
                word_list = ["The", "From", "A", "An", "And", "Is", "But", "For",
                             "Nor", "Or", "So", "Of", "To", "On", "At", "As"]
                if word in word_list:
                    raise ValidationException(f"Title contains a capitalized '{word}' when it should not.")
                elif "By" == word and not title.endswith("By"):
                    # This is OK: Order By
                    # This is NOT OK: Search By String
                    raise ValidationException("Title contains a capitalized 'By' when it should not.")
                elif "Of" == word and not title.endswith("Of"):
                    # This is OK: Member Of
                    # This is NOT OK: Type Of String
                    raise ValidationException("Title contains a capitalized 'Of' when it should not.")
                elif not word[0].isupper() and not word.capitalize() in word_list:
                    if not word.lower() == "by" or word.lower() == "of":
                        raise ValidationException(f"Title contains a lowercase '{word}' when it should not.")

    @staticmethod
    def validate_actions(dict_, dict_key):
        if dict_key in dict_:
            TitleValidator.validate_dictionary(dict_, dict_key)
            for key, value in dict_[dict_key].items():
                if "input" in value:
                    TitleValidator.validate_dictionary(value, "input")
                if "output" in value:
                    TitleValidator.validate_dictionary(value, "output")

    @staticmethod
    def validate_dictionary(dict_, dict_key):
        if dict_key in dict_:
            if not dict_[dict_key]:
                return

            for key, value in dict_[dict_key].items():
                if "name" in value:
                    raise ValidationException(f"Deprecated 'name' key '{value}' found when 'title' should be used instead.")
                if "title" in value:
                    try:
                        TitleValidator.validate_title(value["title"], plugin_title=False)
                    except Exception as e:
                        raise ValidationException(f"{dict_key} key '{key}'\'s title ends with period when it should not.", e)

    @staticmethod
    def validate_plugin_title(spec):
        if "title" not in spec.spec_dictionary():
            raise ValidationException("Plugin title is missing.")

        try:
            TitleValidator.validate_title(spec.spec_dictionary()["title"], plugin_title=True)
        except Exception as e:
            raise ValidationException("Plugin title not valid.", e)

    def validate(self, spec):
        TitleValidator.validate_plugin_title(spec)
        TitleValidator.validate_actions(spec.spec_dictionary(), "actions")
        TitleValidator.validate_actions(spec.spec_dictionary(), "triggers")
        TitleValidator.validate_actions(spec.spec_dictionary(), "connection")
